pub struct TreeUpdateBatch {
pub node_batch: NodeBatch,
pub stale_node_index_batch: StaleNodeIndexBatch,
pub node_stats: Vec<NodeStats>,
}Expand description
This is a wrapper of NodeBatch,
StaleNodeIndexBatch and some stats of nodes that represents
the incremental updates of a tree and pruning indices after applying a write set,
which is a vector of hashed_account_address and new_value pairs.
Fields
node_batch: NodeBatchstale_node_index_batch: StaleNodeIndexBatchnode_stats: Vec<NodeStats>Trait Implementations
Sourceimpl Clone for TreeUpdateBatch
impl Clone for TreeUpdateBatch
Sourcefn clone(&self) -> TreeUpdateBatch
fn clone(&self) -> TreeUpdateBatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TreeUpdateBatch
impl Debug for TreeUpdateBatch
Sourceimpl Decode for TreeUpdateBatch
impl Decode for TreeUpdateBatch
Sourcefn decode_ext(
reader: &mut impl Read,
dedupe_decoder: Option<&mut DedupeDecoder>,
) -> Result<Self>
fn decode_ext( reader: &mut impl Read, dedupe_decoder: Option<&mut DedupeDecoder>, ) -> Result<Self>
Sourcefn decode_len(reader: &mut impl Read) -> Result<usize, Error>
fn decode_len(reader: &mut impl Read) -> Result<usize, Error>
Decodes a collection length previously encoded with
Encode::encode_len.Sourcefn decode_discriminant(reader: &mut impl Read) -> Result<usize, Error>
fn decode_discriminant(reader: &mut impl Read) -> Result<usize, Error>
Decodes an enum discriminant previously encoded with
Encode::encode_discriminant. Read moreSourceimpl Default for TreeUpdateBatch
impl Default for TreeUpdateBatch
Sourcefn default() -> TreeUpdateBatch
fn default() -> TreeUpdateBatch
Returns the “default value” for a type. Read more
Sourceimpl Encode for TreeUpdateBatch
impl Encode for TreeUpdateBatch
Sourcefn encode_ext(
&self,
writer: &mut impl Write,
dedupe_encoder: Option<&mut DedupeEncoder>,
) -> Result<usize>
fn encode_ext( &self, writer: &mut impl Write, dedupe_encoder: Option<&mut DedupeEncoder>, ) -> Result<usize>
Sourcefn encode_len(len: usize, writer: &mut impl Write) -> Result<usize, Error>
fn encode_len(len: usize, writer: &mut impl Write) -> Result<usize, Error>
Encodes a collection length in a compact form.
impl Eq for TreeUpdateBatch
Sourceimpl PartialEq for TreeUpdateBatch
impl PartialEq for TreeUpdateBatch
Sourcefn eq(&self, other: &TreeUpdateBatch) -> bool
fn eq(&self, other: &TreeUpdateBatch) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TreeUpdateBatch